[Libreoffice-commits] core.git: 7 commits - chart2/source cli_ure/source compilerplugins/clang connectivity/source cppuhelper/source dbaccess/source drawinglayer/source editeng/source extensions/source extensions/test filter/source forms/qa include/filter scp2/source sc/source svx/source sw/sdi sw/source ucb/source vcl/source

Noel Grandin noel at peralex.com
Tue Oct 13 01:08:40 PDT 2015


 chart2/source/controller/chartapiwrapper/ChartDataWrapper.cxx     |    2 
 chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx |    2 
 chart2/source/controller/main/ChartModelClone.cxx                 |    2 
 chart2/source/controller/main/SelectionHelper.cxx                 |    1 
 chart2/source/tools/OPropertySet.cxx                              |    2 
 cli_ure/source/climaker/climaker_emit.cxx                         |    7 
 compilerplugins/clang/mergeclasses.results                        |    5 
 connectivity/source/drivers/postgresql/pq_xkeycolumns.cxx         |  114 ----------
 cppuhelper/source/component_context.cxx                           |    4 
 dbaccess/source/ui/dlg/odbcconfig.cxx                             |   26 --
 dbaccess/source/ui/dlg/odbcconfig.hxx                             |   52 +---
 dbaccess/source/ui/dlg/sqlmessage.cxx                             |   48 +---
 drawinglayer/source/processor2d/hittestprocessor2d.cxx            |   41 ---
 editeng/source/editeng/editundo.cxx                               |    2 
 extensions/source/propctrlr/browserlistbox.cxx                    |   12 -
 extensions/source/propctrlr/browserlistbox.hxx                    |   27 --
 extensions/test/ole/AxTestComponents/Basic.h                      |    2 
 filter/source/msfilter/escherex.cxx                               |   12 -
 forms/qa/integration/forms/FormControlTest.java                   |    2 
 include/filter/msfilter/escherex.hxx                              |    4 
 sc/source/ui/undo/undodat.cxx                                     |    2 
 scp2/source/ooo/module_pdfimport.scp                              |    3 
 svx/source/svdraw/svddrgmt.cxx                                    |   15 -
 sw/sdi/_textsh.sdi                                                |    2 
 sw/sdi/annotsh.sdi                                                |    2 
 sw/sdi/drwtxtsh.sdi                                               |    2 
 sw/source/core/doc/doccomp.cxx                                    |   77 ++----
 sw/source/core/edit/edfld.cxx                                     |    2 
 sw/source/filter/html/css1atr.cxx                                 |    1 
 sw/source/filter/html/htmlcss1.cxx                                |    4 
 sw/source/filter/html/htmlctxt.cxx                                |    2 
 sw/source/filter/html/parcss1.cxx                                 |    8 
 sw/source/filter/html/svxcss1.cxx                                 |   12 -
 sw/source/filter/html/svxcss1.hxx                                 |    3 
 ucb/source/ucp/webdav/SerfPropPatchReqProcImpl.cxx                |    1 
 vcl/source/gdi/pdfwriter_impl.cxx                                 |    2 
 36 files changed, 102 insertions(+), 403 deletions(-)

New commits:
commit ec20e65469924868fdc02960ef3ed07b245c9c18
Author: Noel Grandin <noel at peralex.com>
Date:   Mon Oct 12 14:35:25 2015 +0200

    loplugin:mergeclasses, merge IControlContext with OBrowserListBox
    
    Change-Id: Ib3e54c9fe8d9445ad799e4b06c41443093af87fb

diff --git a/compilerplugins/clang/mergeclasses.results b/compilerplugins/clang/mergeclasses.results
index 8784c01..5d77cd6 100644
--- a/compilerplugins/clang/mergeclasses.results
+++ b/compilerplugins/clang/mergeclasses.results
@@ -135,7 +135,6 @@ merge oox::ole::OleObjectInfo with oox::vml::OleObjectInfo
 merge oox::xls::IWorksheetProgress with oox::xls::WorksheetGlobals
 merge pcr::(anonymous namespace)::ISQLCommandPropertyUI with pcr::(anonymous namespace)::SQLCommandPropertyUI
 merge pcr::IButtonClickListener with pcr::OBrowserListBox
-merge pcr::IControlContext with pcr::OBrowserListBox
 merge pcr::IModifyListener with pcr::CommonBehaviourControl
 merge pcr::IPropertyControlObserver with pcr::OPropertyBrowserController
 merge pcr::IPropertyInfoService with pcr::OPropertyInfoService
diff --git a/extensions/source/propctrlr/browserlistbox.hxx b/extensions/source/propctrlr/browserlistbox.hxx
index 0410114..8bfa467 100644
--- a/extensions/source/propctrlr/browserlistbox.hxx
+++ b/extensions/source/propctrlr/browserlistbox.hxx
@@ -69,22 +69,8 @@ namespace pcr
     typedef ::std::vector< ListBoxLine > ListBoxLines;
 
 
-    /** non-UNO version of XPropertyControlContext
-    */
-    class SAL_NO_VTABLE IControlContext
-    {
-    public:
-        virtual void SAL_CALL focusGained( const css::uno::Reference< css::inspection::XPropertyControl >& Control ) throw (css::uno::RuntimeException) = 0;
-        virtual void SAL_CALL valueChanged( const css::uno::Reference< css::inspection::XPropertyControl >& Control ) throw (css::uno::RuntimeException) = 0;
-        virtual void SAL_CALL activateNextControl( const css::uno::Reference< css::inspection::XPropertyControl >& CurrentControl ) throw (css::uno::RuntimeException) = 0;
-
-    protected:
-        ~IControlContext() {}
-    };
-
     class OBrowserListBox   :public Control
                             ,public IButtonClickListener
-                            ,public IControlContext
                             ,public PcrClient
     {
     protected:
@@ -156,15 +142,14 @@ namespace pcr
         sal_Int32                   GetMinimumHeight();
 
 
-        bool    IsModified( ) const;
-        void        CommitModified( );
+        bool                        IsModified( ) const;
+        void                        CommitModified( );
 
-    protected:
-        // IControlContext
-        virtual void SAL_CALL focusGained( const css::uno::Reference< css::inspection::XPropertyControl >& Control ) throw (css::uno::RuntimeException) override;
-        virtual void SAL_CALL valueChanged( const css::uno::Reference< css::inspection::XPropertyControl >& Control ) throw (css::uno::RuntimeException) override;
-        virtual void SAL_CALL activateNextControl( const css::uno::Reference< css::inspection::XPropertyControl >& CurrentControl ) throw (css::uno::RuntimeException) override;
+        void SAL_CALL               focusGained( const css::uno::Reference< css::inspection::XPropertyControl >& Control ) throw (css::uno::RuntimeException);
+        void SAL_CALL               valueChanged( const css::uno::Reference< css::inspection::XPropertyControl >& Control ) throw (css::uno::RuntimeException);
+        void SAL_CALL               activateNextControl( const css::uno::Reference< css::inspection::XPropertyControl >& CurrentControl ) throw (css::uno::RuntimeException);
 
+    protected:
         // IButtonClickListener
         void    buttonClicked( OBrowserLine* _pLine, bool _bPrimary ) override;
 
commit 38b4b7590d520fb53fabc40c5c95346546b2fdc3
Author: Noel Grandin <noel at peralex.com>
Date:   Mon Oct 12 14:30:06 2015 +0200

    loplugin:mergeclasses, merge OOdbcLibWrapper with OOdbcEnumeration
    
    Change-Id: I2e564e90c11bb46022a5e258ad013aeb2fe4ca2e

diff --git a/compilerplugins/clang/mergeclasses.results b/compilerplugins/clang/mergeclasses.results
index 147c46a..8784c01 100644
--- a/compilerplugins/clang/mergeclasses.results
+++ b/compilerplugins/clang/mergeclasses.results
@@ -110,7 +110,6 @@ merge cppu::PropertySetMixinImpl with cppu::PropertySetMixin
 merge dbaccess::IPropertyContainer with dbaccess::OColumn
 merge dbaccess::IRefreshListener with dbaccess::OConnection
 merge dbaui::IEntryFilter with dbaui::(anonymous namespace)::FilterByEntryDataId
-merge dbaui::OOdbcLibWrapper with dbaui::OOdbcEnumeration
 merge dbaui::SbaGridListener with dbaui::SbaXDataBrowserController
 merge dbmm::IMigrationProgress with dbmm::ProgressPage
 merge dbmm::IProgressConsumer with dbmm::ProgressDelegator
diff --git a/dbaccess/source/ui/dlg/odbcconfig.cxx b/dbaccess/source/ui/dlg/odbcconfig.cxx
index b04aa69..e6308c7 100644
--- a/dbaccess/source/ui/dlg/odbcconfig.cxx
+++ b/dbaccess/source/ui/dlg/odbcconfig.cxx
@@ -69,16 +69,8 @@ typedef SQLRETURN (SQL_API* TSQLDataSources) (SQLHENV EnvironmentHandle, SQLUSMA
 #endif
 
 // OOdbcLibWrapper
-#ifdef HAVE_ODBC_SUPPORT
-OOdbcLibWrapper::OOdbcLibWrapper()
-    :m_pOdbcLib(NULL)
-{
-
-}
-
-#endif
 
-bool OOdbcLibWrapper::load(const sal_Char* _pLibPath)
+bool OOdbcEnumeration::load(const sal_Char* _pLibPath)
 {
     m_sLibPath = OUString::createFromAscii(_pLibPath);
 #ifdef HAVE_ODBC_SUPPORT
@@ -90,7 +82,7 @@ bool OOdbcLibWrapper::load(const sal_Char* _pLibPath)
 #endif
 }
 
-void OOdbcLibWrapper::unload()
+void OOdbcEnumeration::unload()
 {
 #ifdef HAVE_ODBC_SUPPORT
     if (isLoaded())
@@ -101,18 +93,12 @@ void OOdbcLibWrapper::unload()
 #endif
 }
 
-oslGenericFunction OOdbcLibWrapper::loadSymbol(const sal_Char* _pFunctionName)
+oslGenericFunction OOdbcEnumeration::loadSymbol(const sal_Char* _pFunctionName)
 {
     return osl_getFunctionSymbol(m_pOdbcLib, OUString::createFromAscii(_pFunctionName).pData);
 }
 
-OOdbcLibWrapper::~OOdbcLibWrapper()
-{
-    unload();
-
-}
 
-// OOdbcEnumeration
 struct OdbcTypesImpl
 {
 #ifdef HAVE_ODBC_SUPPORT
@@ -124,8 +110,9 @@ struct OdbcTypesImpl
 };
 
 OOdbcEnumeration::OOdbcEnumeration()
+    :m_pOdbcLib(NULL)
 #ifdef HAVE_ODBC_SUPPORT
-    :m_pAllocHandle(NULL)
+    ,m_pAllocHandle(NULL)
     ,m_pFreeHandle(NULL)
     ,m_pSetEnvAttr(NULL)
     ,m_pDataSources(NULL)
@@ -161,9 +148,10 @@ OOdbcEnumeration::~OOdbcEnumeration()
 {
     freeEnv();
     delete m_pImpl;
-
+    unload();
 }
 
+// OOdbcEnumeration
 bool OOdbcEnumeration::allocEnv()
 {
     OSL_ENSURE(isLoaded(), "OOdbcEnumeration::allocEnv: not loaded!");
diff --git a/dbaccess/source/ui/dlg/odbcconfig.hxx b/dbaccess/source/ui/dlg/odbcconfig.hxx
index 3059b1d..3142f5c 100644
--- a/dbaccess/source/ui/dlg/odbcconfig.hxx
+++ b/dbaccess/source/ui/dlg/odbcconfig.hxx
@@ -38,42 +38,13 @@
 namespace dbaui
 {
 
-// OOdbcLibWrapper
-/** base for helper classes wrapping functionality from an ODBC library
-*/
-class OOdbcLibWrapper
-{
-    oslModule           m_pOdbcLib;     // the library handle
-    OUString     m_sLibPath;     // the path to the library
-
-public:
-#ifdef HAVE_ODBC_SUPPORT
-    bool    isLoaded() const { return NULL != m_pOdbcLib; }
-#else
-    sal_Bool    isLoaded() const { return sal_False; }
-#endif
-    OUString getLibraryName() const { return m_sLibPath; }
-
-protected:
-#ifndef HAVE_ODBC_SUPPORT
-    OOdbcLibWrapper() : m_pOdbcLib(NULL) { }
-#else
-    OOdbcLibWrapper();
-#endif
-    ~OOdbcLibWrapper();
-
-    oslGenericFunction  loadSymbol(const sal_Char* _pFunctionName);
-
-    /// load the lib
-    bool    load(const sal_Char* _pLibPath);
-    /// unload the lib
-    void        unload();
-};
-
 // OOdbcEnumeration
 struct OdbcTypesImpl;
-class OOdbcEnumeration : public OOdbcLibWrapper
+class OOdbcEnumeration
 {
+    oslModule        m_pOdbcLib;     // the library handle
+    OUString         m_sLibPath;     // the path to the library
+
 #ifdef HAVE_ODBC_SUPPORT
     // entry points for ODBC administration
     oslGenericFunction  m_pAllocHandle;
@@ -90,11 +61,24 @@ public:
     OOdbcEnumeration();
     ~OOdbcEnumeration();
 
+#ifdef HAVE_ODBC_SUPPORT
+    bool        isLoaded() const { return NULL != m_pOdbcLib; }
+#else
+    bool        isLoaded() const { return false; }
+#endif
+    OUString    getLibraryName() const { return m_sLibPath; }
+
     void        getDatasourceNames(StringBag& _rNames);
 
 protected:
+    oslGenericFunction  loadSymbol(const sal_Char* _pFunctionName);
+
+    /// load the lib
+    bool        load(const sal_Char* _pLibPath);
+    /// unload the lib
+    void        unload();
     /// ensure that an ODBC environment is allocated
-    bool    allocEnv();
+    bool        allocEnv();
     /// free any allocated ODBC environment
     void        freeEnv();
 };
commit ade2ba503f345fcbd2ac889a749db584a94a3043
Author: Noel Grandin <noel at peralex.com>
Date:   Mon Oct 12 14:22:39 2015 +0200

    loplugin:mergeclasses, merge ILabelProvider with LabelProvider
    
    Change-Id: I8fb231b4189c09d8e049855d38b0f1eb518ac2b9

diff --git a/compilerplugins/clang/mergeclasses.results b/compilerplugins/clang/mergeclasses.results
index 61d9cd4..147c46a 100644
--- a/compilerplugins/clang/mergeclasses.results
+++ b/compilerplugins/clang/mergeclasses.results
@@ -109,7 +109,6 @@ merge cppcanvas::Renderer with cppcanvas::internal::ImplRenderer
 merge cppu::PropertySetMixinImpl with cppu::PropertySetMixin
 merge dbaccess::IPropertyContainer with dbaccess::OColumn
 merge dbaccess::IRefreshListener with dbaccess::OConnection
-merge dbaui::(anonymous namespace)::ILabelProvider with dbaui::(anonymous namespace)::LabelProvider
 merge dbaui::IEntryFilter with dbaui::(anonymous namespace)::FilterByEntryDataId
 merge dbaui::OOdbcLibWrapper with dbaui::OOdbcEnumeration
 merge dbaui::SbaGridListener with dbaui::SbaXDataBrowserController
diff --git a/dbaccess/source/ui/dlg/sqlmessage.cxx b/dbaccess/source/ui/dlg/sqlmessage.cxx
index 0f9e9d3..8ab9396 100644
--- a/dbaccess/source/ui/dlg/sqlmessage.cxx
+++ b/dbaccess/source/ui/dlg/sqlmessage.cxx
@@ -55,14 +55,6 @@ namespace dbaui
 
 namespace
 {
-    class ILabelProvider
-    {
-    public:
-        virtual OUString  getLabel() const = 0;
-
-        virtual ~ILabelProvider() { };
-    };
-
     class ImageProvider
     {
     private:
@@ -84,7 +76,7 @@ namespace
         }
     };
 
-    class LabelProvider : public ILabelProvider
+    class LabelProvider
     {
     private:
         OUString  m_label;
@@ -94,7 +86,7 @@ namespace
         {
         }
 
-        virtual OUString  getLabel() const override
+        OUString  getLabel() const
         {
             return m_label;
         }
@@ -106,9 +98,9 @@ namespace
         mutable std::shared_ptr< ImageProvider >   m_pErrorImage;
         mutable std::shared_ptr< ImageProvider >   m_pWarningsImage;
         mutable std::shared_ptr< ImageProvider >   m_pInfoImage;
-        mutable std::shared_ptr< ILabelProvider >   m_pErrorLabel;
-        mutable std::shared_ptr< ILabelProvider >   m_pWarningsLabel;
-        mutable std::shared_ptr< ILabelProvider >   m_pInfoLabel;
+        mutable std::shared_ptr< LabelProvider >   m_pErrorLabel;
+        mutable std::shared_ptr< LabelProvider >   m_pWarningsLabel;
+        mutable std::shared_ptr< LabelProvider >   m_pInfoLabel;
 
     public:
         ProviderFactory()
@@ -141,9 +133,9 @@ namespace
             return *ppProvider;
         }
 
-        std::shared_ptr< ILabelProvider >   getLabelProvider( SQLExceptionInfo::TYPE _eType, bool _bSubLabel ) const
+        std::shared_ptr< LabelProvider >   getLabelProvider( SQLExceptionInfo::TYPE _eType, bool _bSubLabel ) const
         {
-            std::shared_ptr< ILabelProvider >* ppProvider( &m_pErrorLabel );
+            std::shared_ptr< LabelProvider >* ppProvider( &m_pErrorLabel );
             sal_uInt16 nLabelID( STR_EXCEPTION_ERROR );
 
             switch ( _eType )
@@ -174,7 +166,7 @@ namespace
         SQLExceptionInfo::TYPE                  eType;
 
         std::shared_ptr< ImageProvider >        pImageProvider;
-        std::shared_ptr< ILabelProvider >       pLabelProvider;
+        std::shared_ptr< LabelProvider >        pLabelProvider;
 
         bool                                    bSubEntry;
 
commit 3e5f9c03433d3480080276640a924b2aa0bdc227
Author: Noel Grandin <noel at peralex.com>
Date:   Mon Oct 12 14:21:29 2015 +0200

    loplugin:mergeclasses, merge IImageProvider with ImageProvider
    
    Change-Id: I6af8b1ab9198439af60e38a9adc6bdd29d20ab52

diff --git a/compilerplugins/clang/mergeclasses.results b/compilerplugins/clang/mergeclasses.results
index 39f5e70..61d9cd4 100644
--- a/compilerplugins/clang/mergeclasses.results
+++ b/compilerplugins/clang/mergeclasses.results
@@ -109,7 +109,6 @@ merge cppcanvas::Renderer with cppcanvas::internal::ImplRenderer
 merge cppu::PropertySetMixinImpl with cppu::PropertySetMixin
 merge dbaccess::IPropertyContainer with dbaccess::OColumn
 merge dbaccess::IRefreshListener with dbaccess::OConnection
-merge dbaui::(anonymous namespace)::IImageProvider with dbaui::(anonymous namespace)::ImageProvider
 merge dbaui::(anonymous namespace)::ILabelProvider with dbaui::(anonymous namespace)::LabelProvider
 merge dbaui::IEntryFilter with dbaui::(anonymous namespace)::FilterByEntryDataId
 merge dbaui::OOdbcLibWrapper with dbaui::OOdbcEnumeration
diff --git a/dbaccess/source/ui/dlg/sqlmessage.cxx b/dbaccess/source/ui/dlg/sqlmessage.cxx
index 3a0b31e..0f9e9d3 100644
--- a/dbaccess/source/ui/dlg/sqlmessage.cxx
+++ b/dbaccess/source/ui/dlg/sqlmessage.cxx
@@ -55,14 +55,6 @@ namespace dbaui
 
 namespace
 {
-    class IImageProvider
-    {
-    public:
-        virtual Image   getImage() const = 0;
-
-        virtual ~IImageProvider() { }
-    };
-
     class ILabelProvider
     {
     public:
@@ -71,7 +63,7 @@ namespace
         virtual ~ILabelProvider() { };
     };
 
-    class ImageProvider : public IImageProvider
+    class ImageProvider
     {
     private:
         sal_uInt16  m_defaultImageID;
@@ -84,7 +76,7 @@ namespace
         {
         }
 
-        virtual Image getImage() const override
+        Image getImage() const
         {
             if ( !m_defaultImage )
                 m_defaultImage = Image( ModuleRes( m_defaultImageID ) );
@@ -111,9 +103,9 @@ namespace
     class ProviderFactory
     {
     private:
-        mutable std::shared_ptr< IImageProvider >   m_pErrorImage;
-        mutable std::shared_ptr< IImageProvider >   m_pWarningsImage;
-        mutable std::shared_ptr< IImageProvider >   m_pInfoImage;
+        mutable std::shared_ptr< ImageProvider >   m_pErrorImage;
+        mutable std::shared_ptr< ImageProvider >   m_pWarningsImage;
+        mutable std::shared_ptr< ImageProvider >   m_pInfoImage;
         mutable std::shared_ptr< ILabelProvider >   m_pErrorLabel;
         mutable std::shared_ptr< ILabelProvider >   m_pWarningsLabel;
         mutable std::shared_ptr< ILabelProvider >   m_pInfoLabel;
@@ -123,9 +115,9 @@ namespace
         {
         }
 
-        std::shared_ptr< IImageProvider >   getImageProvider( SQLExceptionInfo::TYPE _eType ) const
+        std::shared_ptr< ImageProvider >   getImageProvider( SQLExceptionInfo::TYPE _eType ) const
         {
-            std::shared_ptr< IImageProvider >* ppProvider( &m_pErrorImage );
+            std::shared_ptr< ImageProvider >* ppProvider( &m_pErrorImage );
             sal_uInt16 nNormalImageID( BMP_EXCEPTION_ERROR );
 
             switch ( _eType )
@@ -181,8 +173,8 @@ namespace
     {
         SQLExceptionInfo::TYPE                  eType;
 
-        std::shared_ptr< IImageProvider >   pImageProvider;
-        std::shared_ptr< ILabelProvider >   pLabelProvider;
+        std::shared_ptr< ImageProvider >        pImageProvider;
+        std::shared_ptr< ILabelProvider >       pLabelProvider;
 
         bool                                    bSubEntry;
 
commit 1716b3a338b19b9d1be39696866b376aed216c9a
Author: Noel Grandin <noel at peralex.com>
Date:   Mon Oct 12 13:43:35 2015 +0200

    remove some useless comments
    
    found with git grep '// /'
    
    Change-Id: I948cf9ae61bbbf2ec706ca5b0572c4f27c58c745

diff --git a/chart2/source/controller/chartapiwrapper/ChartDataWrapper.cxx b/chart2/source/controller/chartapiwrapper/ChartDataWrapper.cxx
index 8069243..87427b2 100644
--- a/chart2/source/controller/chartapiwrapper/ChartDataWrapper.cxx
+++ b/chart2/source/controller/chartapiwrapper/ChartDataWrapper.cxx
@@ -682,7 +682,7 @@ void ChartDataWrapper::applyData( lcl_Operator& rDataOperator )
     uno::Sequence< beans::PropertyValue > aArguments( DataSourceHelper::createArguments(
             aRangeString, aSequenceMapping, bUseColumns, bFirstCellAsLabel, bHasCategories ) );
 
-    // /-- locked controllers
+    // -- locked controllers
     ControllerLockGuardUNO aCtrlLockGuard( uno::Reference< frame::XModel >( xChartDoc, uno::UNO_QUERY ));
 
     // create and attach new data source
diff --git a/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx b/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx
index 1f49652..b93dfc5 100644
--- a/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx
+++ b/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx
@@ -838,10 +838,8 @@ void SAL_CALL ChartDocumentWrapper::attachData( const Reference< XChartData >& x
     if( !xNewData.is() )
         return;
 
-    // /-- locked controllers
     ControllerLockGuardUNO aCtrlLockGuard( Reference< frame::XModel >( m_spChart2ModelContact->getChart2Document(), uno::UNO_QUERY ));
     m_xChartData.set( new ChartDataWrapper( m_spChart2ModelContact, xNewData ) );
-    // \-- locked controllers
 }
 
 // ____ XModel ____
diff --git a/chart2/source/controller/main/ChartModelClone.cxx b/chart2/source/controller/main/ChartModelClone.cxx
index 6611cbf..c6f7ee4 100644
--- a/chart2/source/controller/main/ChartModelClone.cxx
+++ b/chart2/source/controller/main/ChartModelClone.cxx
@@ -190,7 +190,7 @@ namespace chart
         ENSURE_OR_RETURN_VOID( i_modelToCopyFrom.is(), "ChartModelElement::applyModelContentToModel: invalid source model!" );
         try
         {
-            // /-- loccked controllers of destination
+            // locked controllers of destination
             ControllerLockGuardUNO aLockedControllers( i_model );
             Reference< XChartDocument > xSource( i_modelToCopyFrom, UNO_QUERY_THROW );
             Reference< XChartDocument > xDestination( i_model, UNO_QUERY_THROW );
diff --git a/chart2/source/controller/main/SelectionHelper.cxx b/chart2/source/controller/main/SelectionHelper.cxx
index 9793dcc..4dbdd26 100644
--- a/chart2/source/controller/main/SelectionHelper.cxx
+++ b/chart2/source/controller/main/SelectionHelper.cxx
@@ -385,7 +385,6 @@ OUString SelectionHelper::getHitObjectCID(
     DrawViewWrapper& rDrawViewWrapper,
     bool bGetDiagramInsteadOf_Wall )
 {
-    // //- solar mutex
     SolarMutexGuard aSolarGuard;
     OUString aRet;
 
diff --git a/chart2/source/tools/OPropertySet.cxx b/chart2/source/tools/OPropertySet.cxx
index 939741c..1fda7e3 100644
--- a/chart2/source/tools/OPropertySet.cxx
+++ b/chart2/source/tools/OPropertySet.cxx
@@ -90,7 +90,7 @@ Any SAL_CALL OPropertySet::queryInterface( const uno::Type& aType )
 
 #define LCL_PROP_CPPUTYPE(t) (cppu::UnoType<t>::get())
 
-// // ____ XTypeProvider ____
+//  ____ XTypeProvider ____
 Sequence< uno::Type > SAL_CALL
     OPropertySet::getTypes()
     throw (uno::RuntimeException, std::exception)
diff --git a/cli_ure/source/climaker/climaker_emit.cxx b/cli_ure/source/climaker/climaker_emit.cxx
index 2ba5c62..79b41a1 100644
--- a/cli_ure/source/climaker/climaker_emit.cxx
+++ b/cli_ure/source/climaker/climaker_emit.cxx
@@ -565,13 +565,6 @@ Assembly ^ TypeEmitter::type_resolve(
     ::System::Type ^ ret_type = get_type( cts_name, false /* no exc */ );
     if (nullptr == ret_type)
     {
-//         Emit::EnumBuilder * enum_builder =
-//             m_module_builder->DefineEnum(
-//                 cts_name,
-//                 (TypeAttributes) (TypeAttributes::Public |
-// //                                   TypeAttributes::Sealed |
-//                                   TypeAttributes::AnsiClass),
-//                 __typeof (::System::Int32) );
         // workaround enum builder bug
         Emit::TypeBuilder ^ enum_builder =
             m_module_builder->DefineType(
diff --git a/connectivity/source/drivers/postgresql/pq_xkeycolumns.cxx b/connectivity/source/drivers/postgresql/pq_xkeycolumns.cxx
index ae99c81..bfdfd24 100644
--- a/connectivity/source/drivers/postgresql/pq_xkeycolumns.cxx
+++ b/connectivity/source/drivers/postgresql/pq_xkeycolumns.cxx
@@ -169,120 +169,6 @@ void KeyColumns::refresh()
 }
 
 
-// void alterColumnByDescriptor(
-//     const OUString & schemaName,
-//     const OUString & tableName,
-//     rtl_TextEncoding encoding,
-//     const Reference< XStatement > &stmt,
-//     const com::sun::star::uno::Reference< com::sun::star::beans::XPropertySet > & past,
-//     const com::sun::star::uno::Reference< com::sun::star::beans::XPropertySet > & future)
-// {
-//     Statics & st  = getStatics();
-
-// //     if( past->getPropertyValue( st.TABLE_NAME ) != future->getPropertyValue( st.TABLE_NAME ) ||
-// //         past->getPropertyValue( st.SCHEMA_NAME ) != future->getPropertyValue( st.SCHEMA_NAME ))
-// //     {
-// //         OUStringBuffer buf(128);
-// //         buf.append( "Can't move column " );
-// //         buf.append( extractStringProperty( past, st.COLUMN_NAME ) );
-// //         buf.append( " from table " );
-// //         buf.append( extractStringProperty( past, st.TABLE_NAME ) );
-// //         buf.append( " to table " );
-// //         buf.append( extractStringProperty( past, st.TABLE_NAME ) );
-// //         throw SQLException( buf.makeStringAndClear() );
-// //     }
-
-// //     OUString tableName = extractStringProperty( past, st.TABLE_NAME );
-// //     OUString schemaName = extractStringProperty( past, st.SCHEMA_NAME );
-//     OUString pastColumnName = extractStringProperty( past, st.NAME );
-//     OUString futureColumnName = extractStringProperty( future, st.NAME );
-//     OUString pastTypeName = sqltype2string( past );
-//     OUString futureTypeName = sqltype2string( future );
-
-//     TransactionGuard transaction( stmt );
-
-//     OUStringBuffer buf( 128 );
-//     if( ! pastColumnName.getLength())
-//     {
-//         // create a new column
-//         buf.append( "ALTER TABLE" );
-//         bufferQuoteQualifiedIdentifier( buf, schemaName, tableName );
-//         buf.append( "ADD COLUMN" );
-//         bufferQuoteIdentifier( buf, futureColumnName );
-//         buf.append( futureTypeName );
-//         transaction.executeUpdate( buf.makeStringAndClear() );
-//     }
-//     else
-//     {
-//         if( pastTypeName != futureTypeName )
-//         {
-//             throw RuntimeException(
-//                 "Can't modify column types, drop the column and create a new one" );
-//         }
-
-//         if( pastColumnName != futureColumnName )
-//         {
-//             buf.append( "ALTER TABLE" );
-//             bufferQuoteQualifiedIdentifier( buf, schemaName, tableName );
-//             buf.append( "RENAME COLUMN" );
-//             bufferQuoteIdentifier( buf, pastColumnName );
-//             buf.append( "TO" );
-//             bufferQuoteIdentifier( buf, futureColumnName );
-//             transaction.executeUpdate( buf.makeStringAndClear() );
-//         }
-//     }
-
-//     OUString futureDefaultValue = extractStringProperty( future, st.DEFAULT_VALUE );
-//     OUString pastDefaultValue = extractStringProperty( past, st.DEFAULT_VALUE );
-//     if( futureDefaultValue != pastDefaultValue )
-//     {
-//         buf = OUStringBuffer( 128 );
-//         buf.append( "ALTER TABLE" );
-//         bufferQuoteQualifiedIdentifier( buf, schemaName, tableName );
-//         buf.append( "ALTER COLUMN" );
-//         bufferQuoteIdentifier( buf, futureColumnName );
-//         buf.append( "SET DEFAULT " );
-//         // default value is not quoted, caller needs to quote himself (otherwise
-//         // how to pass e.g. nextval('something' ) ????
-//         buf.append( futureDefaultValue );
-// //        bufferQuoteConstant( buf, defaultValue, encoding );
-//         transaction.executeUpdate( buf.makeStringAndClear() );
-//     }
-
-//     sal_Int32 futureNullable = extractIntProperty( future, st.IS_NULLABLE );
-//     sal_Int32 pastNullable = extractIntProperty( past, st.IS_NULLABLE );
-//     if( futureNullable != pastNullable )
-//     {
-//         buf = OUStringBuffer( 128 );
-//         buf.append( "ALTER TABLE" );
-//         bufferQuoteQualifiedIdentifier( buf, schemaName, tableName );
-//         buf.append( "ALTER COLUMN" );
-//         bufferQuoteIdentifier( buf, futureColumnName );
-//         if( futureNullable == com::sun::star::sdbc::ColumnValue::NO_NULLS )
-//         {
-//             buf.append( "SET" );
-//         }
-//         else
-//         {
-//             buf.append( "DROP" );
-//         }
-//         buf.append( " NOT NULL" );
-//         transaction.executeUpdate( buf.makeStringAndClear() );
-//     }
-
-//     OUString futureComment = extractStringProperty( future, st.DESCRIPTION );
-//     OUString pastComment = extractStringProperty( past, st.DESCRIPTION );
-//     if( futureComment != pastComment )
-//     {
-//         buf = OUStringBuffer( 128 );
-//         buf.append( "COMMENT ON COLUMN" );
-//         bufferQuoteQualifiedIdentifier( buf, schemaName, tableName , futureColumnName );
-//         buf.append( "IS " );
-//         bufferQuoteConstant( buf, futureComment,encoding);
-//         transaction.executeUpdate( buf.makeStringAndClear() );
-//     }
-//     transaction.commit();
-// }
 
 void KeyColumns::appendByDescriptor(
     const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet >& future )
diff --git a/cppuhelper/source/component_context.cxx b/cppuhelper/source/component_context.cxx
index d6e6aaa..62058d4 100644
--- a/cppuhelper/source/component_context.cxx
+++ b/cppuhelper/source/component_context.cxx
@@ -771,9 +771,9 @@ ComponentContext::ComponentContext(
         {
             // singleton entry
             m_map[ rEntry.name ] = new ContextEntry( Any(), true );
-            // /service
+            // service
             m_map[ rEntry.name + "/service" ] = new ContextEntry( rEntry.value, false );
-            // /initial-arguments are provided as optional context entry
+            // initial-arguments are provided as optional context entry
         }
         else
         {
diff --git a/drawinglayer/source/processor2d/hittestprocessor2d.cxx b/drawinglayer/source/processor2d/hittestprocessor2d.cxx
index 9d7bb4b..4e59773 100644
--- a/drawinglayer/source/processor2d/hittestprocessor2d.cxx
+++ b/drawinglayer/source/processor2d/hittestprocessor2d.cxx
@@ -213,21 +213,6 @@ namespace drawinglayer
                     }
                 }
 
-                // This is needed to check hit with 3D shadows, too. HitTest is without shadow
-                // to keep compatible with previous versions. Keeping here as reference
-                //
-                // if(!getHit())
-                // {
-                //     // if scene has shadow, check hit with shadow, too
-                //     const primitive2d::Primitive2DSequence xExtracted2DSceneShadow(rCandidate.getShadow2D(getViewInformation2D()));
-                //
-                //     if(xExtracted2DSceneShadow.hasElements())
-                //     {
-                //         // process extracted 2D content
-                //         process(xExtracted2DSceneShadow);
-                //     }
-                // }
-
                 if(!getHit())
                 {
                     // empty 3D scene; Check for border hit
@@ -236,32 +221,6 @@ namespace drawinglayer
 
                     mbHit = checkHairlineHitWithTolerance(aOutline, getDiscreteHitTolerance());
                 }
-
-                // This is what the previous version did. Keeping it here for reference
-                //
-                // // 2D Scene primitive containing 3D stuff; extract 2D contour in world coordinates
-                // // This may be refined later to an own 3D HitTest renderer which processes the 3D
-                // // geometry directly
-                // const primitive2d::ScenePrimitive2D& rScenePrimitive2DCandidate(static_cast< const primitive2d::ScenePrimitive2D& >(rCandidate));
-                // const primitive2d::Primitive2DSequence xExtracted2DSceneGeometry(rScenePrimitive2DCandidate.getGeometry2D());
-                // const primitive2d::Primitive2DSequence xExtracted2DSceneShadow(rScenePrimitive2DCandidate.getShadow2D(getViewInformation2D()));
-                //
-                // if(xExtracted2DSceneGeometry.hasElements() || xExtracted2DSceneShadow.hasElements())
-                // {
-                //     // process extracted 2D content
-                //     process(xExtracted2DSceneGeometry);
-                //     process(xExtracted2DSceneShadow);
-                // }
-                // else
-                // {
-                //     // empty 3D scene; Check for border hit
-                //     const basegfx::B2DRange aRange(rCandidate.getB2DRange(getViewInformation2D()));
-                //     if(!aRange.isEmpty())
-                //     {
-                //          const basegfx::B2DPolygon aOutline(basegfx::tools::createPolygonFromRect(aRange));
-                //          mbHit = checkHairlineHitWithTolerance(aOutline, getDiscreteHitTolerance());
-                //     }
-                // }
             }
         }
 
diff --git a/editeng/source/editeng/editundo.cxx b/editeng/source/editeng/editundo.cxx
index 597f60c..e581f38 100644
--- a/editeng/source/editeng/editundo.cxx
+++ b/editeng/source/editeng/editundo.cxx
@@ -491,7 +491,7 @@ EditUndoSetAttribs::EditUndoSetAttribs(EditEngine* pEE, const ESelection& rESel,
     aESel(rESel), aNewAttribs(rNewItems)
 {
     // When EditUndoSetAttribs actually is a RemoveAttribs this could be
-    // /recognize by the empty itemset, but then it would have to be caught in
+    // recognize by the empty itemset, but then it would have to be caught in
     // its own place, which possible a setAttribs does with an empty itemset.
     bSetIsRemove = false;
     bRemoveParaAttribs = false;
diff --git a/extensions/test/ole/AxTestComponents/Basic.h b/extensions/test/ole/AxTestComponents/Basic.h
index 13268ca..eec04aa 100644
--- a/extensions/test/ole/AxTestComponents/Basic.h
+++ b/extensions/test/ole/AxTestComponents/Basic.h
@@ -143,12 +143,10 @@ public:
 
     STDMETHOD(defaultvalue1)(/*[in, defaultvalue(10)]*/ long val1,
         /*[in, defaultvalue(3.14)]*/ double* val2,
-        // /*[in, defaultvalue(10)]*/ VARIANT val3,
         /*[in, defaultvalue(100)]*/ VARIANT* val4);
 
         STDMETHOD(defaultvalue2)(/*[in, out, defaultvalue(10)]*/ long* val1,
         /*[in, out, defaultvalue(3.14)]*/ double* val2,
-        // /*[in, out, defaultvalue(10)]*/ VARIANT* val3,
         /*[in, out, defaultvalue(100)]*/ VARIANT* val4);
 
         STDMETHOD(varargfunc1)(/*[in]*/ long val1,/*[in]*/ LPSAFEARRAY val2);
diff --git a/filter/source/msfilter/escherex.cxx b/filter/source/msfilter/escherex.cxx
index 5b576d2..1f6fec5 100644
--- a/filter/source/msfilter/escherex.cxx
+++ b/filter/source/msfilter/escherex.cxx
@@ -4952,11 +4952,11 @@ SvStream* EscherExGlobal::ImplQueryPictureStream()
     return 0;
 }
 
-// /Implementation of an empty stream that silently succeeds, but does nothing.
-// /
-// /In fact, this is a hack.  The right solution is to abstract EscherEx to be
-// /able to work without SvStream; but at the moment it is better to live with
-// /this I guess.
+// Implementation of an empty stream that silently succeeds, but does nothing.
+//
+// In fact, this is a hack.  The right solution is to abstract EscherEx to be
+// able to work without SvStream; but at the moment it is better to live with
+// this I guess.
 class SvNullStream : public SvStream
 {
 protected:
diff --git a/forms/qa/integration/forms/FormControlTest.java b/forms/qa/integration/forms/FormControlTest.java
index de09694..eac4820 100644
--- a/forms/qa/integration/forms/FormControlTest.java
+++ b/forms/qa/integration/forms/FormControlTest.java
@@ -475,7 +475,7 @@ public class FormControlTest extends complexlib.ComplexTestCase implements XSQLE
         if ( databaseContext.hasByName( m_dataSourceName ) )
             namingService.revokeObject( m_dataSourceName );
 
-        // // create a new ODB file, and register it with its URL
+        // create a new ODB file, and register it with its URL
         m_databaseDocument = new HsqlDatabase( m_orb );
         String documentURL = m_databaseDocument.getDocumentURL();
         namingService.registerObject( m_dataSourceName, databaseContext.getByName( documentURL ) );
diff --git a/sc/source/ui/undo/undodat.cxx b/sc/source/ui/undo/undodat.cxx
index 1e1775c..e34fac8 100644
--- a/sc/source/ui/undo/undodat.cxx
+++ b/sc/source/ui/undo/undodat.cxx
@@ -1189,7 +1189,7 @@ void ScUndoImportData::Redo()
                                                     nCol1, nRow1, nCol2, nRow2 );
     }
     bool bMoveCells = pUndoDBData && pRedoDBData &&
-                        pRedoDBData->IsDoSize();        // // the same in old and new
+                        pRedoDBData->IsDoSize();        // the same in old and new
     if (bMoveCells)
     {
         //  Redo: FitBlock, then delete data (needed for CopyToDocument)
diff --git a/scp2/source/ooo/module_pdfimport.scp b/scp2/source/ooo/module_pdfimport.scp
index 3c6add5..5159b19 100644
--- a/scp2/source/ooo/module_pdfimport.scp
+++ b/scp2/source/ooo/module_pdfimport.scp
@@ -13,8 +13,7 @@
 // module as an individual, optional part, so that the core installation does
 // not feature a dependency on a poppler package.
 
-// The
-// /org.openoffice.TypeDetection.Types/Types/pdf_Portable_Document_Format
+// The /org.openoffice.TypeDetection.Types/Types/pdf_Portable_Document_Format
 // configuration node contained in pdfimport.xcd needs to override a
 // node with the same name but which lacks import functionality and
 // which is duplicated across calc, draw, impress, math, writer .xcd
diff --git a/svx/source/svdraw/svddrgmt.cxx b/svx/source/svdraw/svddrgmt.cxx
index 6045443..f1af961 100644
--- a/svx/source/svdraw/svddrgmt.cxx
+++ b/svx/source/svdraw/svddrgmt.cxx
@@ -4021,21 +4021,6 @@ bool SdrDragCrop::EndSdrDrag(bool /*bCopy*/)
     double fScaleX = ( aGraphicSize.Width() - rOldCrop.GetLeft() - rOldCrop.GetRight() ) / (double)aOldRect.GetWidth();
     double fScaleY = ( aGraphicSize.Height() - rOldCrop.GetTop() - rOldCrop.GetBottom() ) / (double)aOldRect.GetHeight();
 
-    // not needed since the modification is done in unit coordinates, free from shear/rotate and mirror
-    // // TTTT may be removed or exchanged by other stuff in aw080
-    // // to correct the never working combination of cropped images and mirroring
-    // // I have to correct the rectangles the calculation is based on here. In the current
-    // // core geometry stuff a vertical mirror is expressed as 180 degree rotation. All
-    // // this can be removed again when aw080 will have cleaned up the old
-    // // (non-)transformation mess in the core.
-    // if(18000 == pObj->GetGeoStat().nRotationAngle)
-    // {
-    //     // old notation of vertical mirror, need to correct diffs since both rects
-    //     // are rotated by 180 degrees
-    //     aOldRect = Rectangle(aOldRect.TopLeft() - (aOldRect.BottomRight() - aOldRect.TopLeft()), aOldRect.TopLeft());
-    //     aNewRect = Rectangle(aNewRect.TopLeft() - (aNewRect.BottomRight() - aNewRect.TopLeft()), aNewRect.TopLeft());
-    // }
-
     sal_Int32 nDiffLeft = aNewRect.Left() - aOldRect.Left();
     sal_Int32 nDiffTop = aNewRect.Top() - aOldRect.Top();
     sal_Int32 nDiffRight = aNewRect.Right() - aOldRect.Right();
diff --git a/sw/sdi/_textsh.sdi b/sw/sdi/_textsh.sdi
index f0793a1..3cd6d8f 100644
--- a/sw/sdi/_textsh.sdi
+++ b/sw/sdi/_textsh.sdi
@@ -1424,7 +1424,7 @@ interface BaseText
         StateMethod = GetTextCtrlState;
         DisableFlags="SW_DISABLE_ON_PROTECTED_CURSOR";
     ]
-    SID_ATTR_CHAR_AUTOKERN // // status(final|play)
+    SID_ATTR_CHAR_AUTOKERN // status(final|play)
     [
         ExecMethod = ExecTextCtrl;
         StateMethod = GetTextCtrlState;
diff --git a/sw/sdi/annotsh.sdi b/sw/sdi/annotsh.sdi
index 12700e2..f0a47dd 100644
--- a/sw/sdi/annotsh.sdi
+++ b/sw/sdi/annotsh.sdi
@@ -261,7 +261,7 @@ interface Annotation : _Annotation
         DisableFlags="SW_DISABLE_ON_PROTECTED_CURSOR";
     ]
 
-    SID_ATTR_CHAR_AUTOKERN // // status(final|play)
+    SID_ATTR_CHAR_AUTOKERN // status(final|play)
     [
         ExecMethod = Exec ;
         StateMethod = GetState ;
diff --git a/sw/sdi/drwtxtsh.sdi b/sw/sdi/drwtxtsh.sdi
index 4bdcea5..1fdf23f 100644
--- a/sw/sdi/drwtxtsh.sdi
+++ b/sw/sdi/drwtxtsh.sdi
@@ -680,7 +680,7 @@ interface TextDrawFont
         StateMethod = GetDrawTextCtrlState ;
         DisableFlags="SW_DISABLE_ON_PROTECTED_CURSOR";
     ]
-    SID_ATTR_CHAR_AUTOKERN // // status(final|play)
+    SID_ATTR_CHAR_AUTOKERN // status(final|play)
     [
         ExecMethod = Execute ;
         StateMethod = GetDrawTextCtrlState ;
diff --git a/sw/source/core/edit/edfld.cxx b/sw/source/core/edit/edfld.cxx
index e4d259d..a8e1543 100644
--- a/sw/source/core/edit/edfld.cxx
+++ b/sw/source/core/edit/edfld.cxx
@@ -251,7 +251,7 @@ void SwEditShell::UpdateFields( SwField &rField )
     SET_CURR_SHELL( this );
     StartAllAction();
     {
-        // // If there are no selections so take the value of the current cursor position.
+        // If there are no selections so take the value of the current cursor position.
         SwMsgPoolItem* pMsgHint = 0;
         SwRefMarkFieldUpdate aRefMkHt( GetOut() );
         sal_uInt16 nFieldWhich = rField.GetTyp()->Which();
diff --git a/sw/source/filter/html/css1atr.cxx b/sw/source/filter/html/css1atr.cxx
index ee400cb..4881531 100644
--- a/sw/source/filter/html/css1atr.cxx
+++ b/sw/source/filter/html/css1atr.cxx
@@ -591,7 +591,6 @@ void SwHTMLWriter::OutStyleSheet( const SwPageDesc& rPageDesc, bool bUsed )
           OutCSS1_SwPageDesc( *this, *pFirstPageDesc, pStylePoolAccess, pTemplate,
                                 nFirstRefPoolId, false );
     }
-// /Feature: PrintExt
 
     // The text body style has to be exported always (if it is changed compared
     // to the template), because it is used as reference for any style
diff --git a/sw/source/filter/html/htmlcss1.cxx b/sw/source/filter/html/htmlcss1.cxx
index eb5f799..ee3faef 100644
--- a/sw/source/filter/html/htmlcss1.cxx
+++ b/sw/source/filter/html/htmlcss1.cxx
@@ -182,7 +182,6 @@ bool SwCSS1Parser::SetFormatBreak( SfxItemSet& rItemSet,
 
     return bSetBreak;
 }
-// /Feature: PrintExt
 
 static void SetCharFormatAttrs( SwCharFormat *pCharFormat, SfxItemSet& rItemSet )
 {
@@ -331,9 +330,7 @@ static void SetTextCollAttrs( SwTextFormatColl *pColl, SfxItemSet& rItemSet,
         }
     }
 
-// Feature: PrintExt
     pCSS1Parser->SetFormatBreak( rItemSet, rPropInfo );
-// /Feature: PrintExt
 
     pColl->SetFormatAttr( rItemSet );
 }
@@ -554,7 +551,6 @@ void SwCSS1Parser::SetPageDescAttrs( const SwPageDesc *pPageDesc,
     if( bChanged )
         ChgPageDesc( pPageDesc, aNewPageDesc );
 }
-// /Feature: PrintExt
 
 SvxBrushItem SwCSS1Parser::makePageDescBackground() const
 {
diff --git a/sw/source/filter/html/htmlctxt.cxx b/sw/source/filter/html/htmlctxt.cxx
index 0184637..665384d 100644
--- a/sw/source/filter/html/htmlctxt.cxx
+++ b/sw/source/filter/html/htmlctxt.cxx
@@ -510,10 +510,8 @@ void SwHTMLParser::InsertAttrs( SfxItemSet &rItemSet,
         }
     }
 
-// Feature: PrintExt
     if( !bCharLvl )
         pCSS1Parser->SetFormatBreak( rItemSet, rPropInfo );
-// /Feature: PrintExt
 
     OSL_ENSURE(aContexts.size() <= nContextStAttrMin ||
             aContexts.back() != pContext,
diff --git a/sw/source/filter/html/parcss1.cxx b/sw/source/filter/html/parcss1.cxx
index 633e6ae..b5042ed 100644
--- a/sw/source/filter/html/parcss1.cxx
+++ b/sw/source/filter/html/parcss1.cxx
@@ -161,13 +161,11 @@ CSS1Token CSS1Parser::GetNextToken()
                         if( aToken.equalsIgnoreAsciiCase( "import" ) )
                             nRet = CSS1_IMPORT_SYM;
                         break;
-// /Feature: PrintExt
                     case 'p':
                     case 'P':
                         if( aToken.equalsIgnoreAsciiCase( "page" ) )
                             nRet = CSS1_PAGE_SYM;
                         break;
-// /Feature: PrintExt
                     }
 
                     // Fehlerbehandlung: '@ident' und alles bis
@@ -691,9 +689,7 @@ void CSS1Parser::ParseStyleSheet()
         case CSS1_IDENT:            // Look-Aheads
         case CSS1_DOT_W_WS:
         case CSS1_HASH:
-// /Feature: PrintExt
         case CSS1_PAGE_SYM:
-// /Feature: PrintExt
             // rule
             bDone = true;
             break;
@@ -718,9 +714,7 @@ void CSS1Parser::ParseStyleSheet()
         case CSS1_IDENT:        // Look-Aheads
         case CSS1_DOT_W_WS:
         case CSS1_HASH:
-// /Feature: PrintExt
         case CSS1_PAGE_SYM:
-// /Feature: PrintExt
             // rule
             ParseRule();
             break;
@@ -917,14 +911,12 @@ CSS1Selector *CSS1Parser::ParseSelector()
             }
             break;
 
-// /Feature: PrintExt
         case CSS1_PAGE_SYM:
             {
                 //  @page
                 pNew = new CSS1Selector( CSS1_SELTYPE_PAGE, aToken );
             }
             break;
-// /Feature: PrintExt
 
         default:
             // wir wissen nicht was kommt, also aufhoehren
diff --git a/sw/source/filter/html/svxcss1.cxx b/sw/source/filter/html/svxcss1.cxx
index ff369b1..bdd1bee 100644
--- a/sw/source/filter/html/svxcss1.cxx
+++ b/sw/source/filter/html/svxcss1.cxx
@@ -214,7 +214,6 @@ static CSS1PropertyEnum const aPageBreakTable[] =
     { 0,                    0                           }
 };
 
-// /Feature: PrintExt
 
 static sal_uInt16 const aBorderWidths[] =
 {
@@ -371,11 +370,9 @@ SvxCSS1PropertyInfo::SvxCSS1PropertyInfo( const SvxCSS1PropertyInfo& rProp ) :
     eTopType( rProp.eTopType ),
     eWidthType( rProp.eWidthType ),
     eHeightType( rProp.eHeightType ),
-// Feature: PrintExt
     eSizeType( rProp.eSizeType ),
     ePageBreakBefore( rProp.ePageBreakBefore ),
     ePageBreakAfter( rProp.ePageBreakAfter )
-// /Feature: PrintExt
 {
     for( size_t i=0; i<SAL_N_ELEMENTS(aBorderInfos); ++i )
         aBorderInfos[i] = rProp.aBorderInfos[i]
@@ -484,8 +481,6 @@ void SvxCSS1PropertyInfo::Merge( const SvxCSS1PropertyInfo& rProp )
     if( rProp.ePageBreakAfter != SVX_CSS1_PBREAK_NONE )
         ePageBreakAfter = rProp.ePageBreakAfter;
 
-// /Feature: PrintExt
-
     if( rProp.eLeftType != SVX_CSS1_LTYPE_NONE )
     {
         eLeftType = rProp.eLeftType;
@@ -2937,10 +2932,6 @@ static void ParseCSS1_size( const CSS1Expression *pExpr,
     }
 }
 
-// /Feature: PrintExt
-
-// Feature: PrintExt
-
 static void ParseCSS1_page_break_xxx( const CSS1Expression *pExpr,
                                       SvxCSS1PageBreak& rPBreak )
 {
@@ -3026,7 +3017,6 @@ static void ParseCSS1_orphans( const CSS1Expression *pExpr,
         rItemSet.Put( aOrphansItem );
     }
 }
-// /Feature: PrintExt
 
 static void ParseCSS1_so_language( const CSS1Expression *pExpr,
                                SfxItemSet &rItemSet,
@@ -3118,14 +3108,12 @@ static CSS1PropEntry aCSS1PropFnTab[] =
     CSS1_PROP_ENTRY(top),
     CSS1_PROP_ENTRY(width),
     CSS1_PROP_ENTRY(height),
-// Feature: PrintExt
     CSS1_PROP_ENTRY(size),
     CSS1_PROP_ENTRY(page_break_before),
     CSS1_PROP_ENTRY(page_break_after),
     CSS1_PROP_ENTRY(page_break_inside),
     CSS1_PROP_ENTRY(widows),
     CSS1_PROP_ENTRY(orphans),
-// /Feature: PrintExt
     CSS1_PROP_ENTRY(so_language)
 };
 
diff --git a/sw/source/filter/html/svxcss1.hxx b/sw/source/filter/html/svxcss1.hxx
index 231fc49..d35f8ef 100644
--- a/sw/source/filter/html/svxcss1.hxx
+++ b/sw/source/filter/html/svxcss1.hxx
@@ -73,7 +73,6 @@ enum SvxCSS1PageBreak
     SVX_CSS1_PBREAK_END
 };
 
-// /Feature: PrintExt
 
 #define CSS1_SCRIPT_WESTERN 0x01
 #define CSS1_SCRIPT_CJK     0x02
@@ -128,12 +127,10 @@ public:
     SvxCSS1LengthType eLeftType, eTopType;
     SvxCSS1LengthType eWidthType, eHeightType;
 
-// Feature: PrintExt
     SvxCSS1SizeType eSizeType;
 
     SvxCSS1PageBreak ePageBreakBefore;
     SvxCSS1PageBreak ePageBreakAfter;
-// /Feature: PrintExt
 
     SvxCSS1PropertyInfo();
     SvxCSS1PropertyInfo( const SvxCSS1PropertyInfo& rProp );
diff --git a/ucb/source/ucp/webdav/SerfPropPatchReqProcImpl.cxx b/ucb/source/ucp/webdav/SerfPropPatchReqProcImpl.cxx
index 06e539d..b87794a 100644
--- a/ucb/source/ucp/webdav/SerfPropPatchReqProcImpl.cxx
+++ b/ucb/source/ucp/webdav/SerfPropPatchReqProcImpl.cxx
@@ -123,7 +123,6 @@ serf_bucket_t * SerfPropPatchReqProcImpl::createSerfRequestBucket( serf_request_
                 }
                 else
                 {
-                    // />
                     aBuffer.append( "/>" );
                 }
 
diff --git a/vcl/source/gdi/pdfwriter_impl.cxx b/vcl/source/gdi/pdfwriter_impl.cxx
index fd02ded..95a46f9 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -5927,7 +5927,7 @@ bool PDFWriterImpl::emitCatalog()
         aLine.append( "/DR " );
         aLine.append( getResourceDictObj() );
         aLine.append( " 0 R" );
-        // /NeedAppearances must not be used if PDF is signed
+        // NeedAppearances must not be used if PDF is signed
         if( m_bIsPDF_A1
 #if !defined(ANDROID) && !defined(IOS)
             || ( m_nSignatureObject != -1 )
commit d6f97a21249668fe401dfcbf1827669c1bb0f043
Author: Noel Grandin <noel at peralex.com>
Date:   Mon Oct 12 13:27:41 2015 +0200

    inline typedef
    
    Change-Id: I6ec88fbdb9bc0e86f4e53eb765eabd5382a25b88

diff --git a/filter/source/msfilter/escherex.cxx b/filter/source/msfilter/escherex.cxx
index 6e72a90..5b576d2 100644
--- a/filter/source/msfilter/escherex.cxx
+++ b/filter/source/msfilter/escherex.cxx
@@ -3885,7 +3885,7 @@ void EscherPersistTable::PtInsert( sal_uInt32 nID, sal_uInt32 nOfs )
 
 sal_uInt32 EscherPersistTable::PtDelete( sal_uInt32 nID )
 {
-    EscherPersistTable_impl::iterator it = maPersistTable.begin();
+    ::std::vector< EscherPersistEntry* >::iterator it = maPersistTable.begin();
     for( ; it != maPersistTable.end() ; ++it )
     {
         if ( (*it)->mnID == nID ) {
diff --git a/include/filter/msfilter/escherex.hxx b/include/filter/msfilter/escherex.hxx
index 97e1987..709fbbd 100644
--- a/include/filter/msfilter/escherex.hxx
+++ b/include/filter/msfilter/escherex.hxx
@@ -971,13 +971,11 @@ public:
 
 
 
-typedef ::std::vector< EscherPersistEntry* > EscherPersistTable_impl;
-
 class MSFILTER_DLLPUBLIC EscherPersistTable
 {
 
 public:
-    EscherPersistTable_impl maPersistTable;
+    ::std::vector< EscherPersistEntry* > maPersistTable;
 
     bool        PtIsID( sal_uInt32 nID );
     void        PtInsert( sal_uInt32 nID, sal_uInt32 nOfs );
commit 9abb98e0199363e7bf9d945e4719ff3a752984b2
Author: Noel Grandin <noel at peralex.com>
Date:   Mon Oct 12 13:25:27 2015 +0200

    loplugin:mergeclass, merge CompareLine with SwCompareLine
    
    Change-Id: Id423939377e6ebb0881a9a7361d6baedbf87931c

diff --git a/compilerplugins/clang/mergeclasses.results b/compilerplugins/clang/mergeclasses.results
index 8e9c77d..39f5e70 100644
--- a/compilerplugins/clang/mergeclasses.results
+++ b/compilerplugins/clang/mergeclasses.results
@@ -2,7 +2,6 @@ merge (anonymous namespace)::Data with cppu::PropertySetMixinImpl::Impl
 merge AbstractMailMergeWizard with AbstractMailMergeWizard_Impl
 merge AbstractSwInsertDBColAutoPilot with AbstractSwInsertDBColAutoPilot_Impl
 merge CffGlobal with CffSubsetterContext
-merge CompareLine with SwCompareLine
 merge DomVisitor with DomExport
 merge DownloadInteractionHandler with UpdateCheck
 merge EscherPersistTable with EscherEx
diff --git a/sw/source/core/doc/doccomp.cxx b/sw/source/core/doc/doccomp.cxx
index 285bfff..db6e381 100644
--- a/sw/source/core/doc/doccomp.cxx
+++ b/sw/source/core/doc/doccomp.cxx
@@ -54,16 +54,32 @@ using namespace ::com::sun::star;
 
 using ::std::vector;
 
-class CompareLine
+class SwCompareLine
 {
+    const SwNode& rNode;
 public:
-    CompareLine() {}
-    virtual ~CompareLine();
+    explicit SwCompareLine( const SwNode& rNd ) : rNode( rNd ) {}
+
+    sal_uLong GetHashValue() const;
+    bool Compare( const SwCompareLine& rLine ) const;
+
+    static sal_uLong GetTextNodeHashValue( const SwTextNode& rNd, sal_uLong nVal );
+    static bool CompareNode( const SwNode& rDstNd, const SwNode& rSrcNd );
+    static bool CompareTextNd( const SwTextNode& rDstNd,
+                              const SwTextNode& rSrcNd );
+
+    bool ChangesInLine( const SwCompareLine& rLine,
+                            SwPaM *& rpInsRing, SwPaM*& rpDelRing ) const;
+
+    const SwNode& GetNode() const { return rNode; }
 
-    virtual sal_uLong GetHashValue() const = 0;
-    virtual bool Compare( const CompareLine& rLine ) const = 0;
+    const SwNode& GetEndNode() const;
+
+    // for debugging
+    OUString GetText() const;
 };
 
+
 class CompareData
 {
 protected:
@@ -77,7 +93,7 @@ private:
     static sal_uLong PrevIdx( const SwNode* pNd );
     static sal_uLong NextIdx( const SwNode* pNd );
 
-    vector< CompareLine* > aLines;
+    vector< SwCompareLine* > aLines;
     bool m_bRecordDiff;
 
     // Truncate beginning and end and add all others to the LinesArray
@@ -124,9 +140,9 @@ public:
         }
 
     size_t GetLineCount() const     { return aLines.size(); }
-    const CompareLine* GetLine( size_t nLine ) const
+    const SwCompareLine* GetLine( size_t nLine ) const
             { return aLines[ nLine ]; }
-    void InsertLine( CompareLine* pLine )
+    void InsertLine( SwCompareLine* pLine )
         { aLines.push_back( pLine ); }
 
     void SetRedlinesToDoc( bool bUseDocInfo );
@@ -167,7 +183,7 @@ class Hash
     struct _HashData
     {
         sal_uLong nNext, nHash;
-        const CompareLine* pLine;
+        const SwCompareLine* pLine;
 
         _HashData()
             : nNext( 0 ), nHash( 0 ), pLine(0) {}
@@ -372,8 +388,6 @@ public:
     }
 };
 
-CompareLine::~CompareLine() {}
-
 CompareData::~CompareData()
 {
     if( pDelRing )
@@ -541,7 +555,7 @@ void Hash::CalcHashValue( CompareData& rData )
     {
         for( size_t n = 0; n < rData.GetLineCount(); ++n )
         {
-            const CompareLine* pLine = rData.GetLine( n );
+            const SwCompareLine* pLine = rData.GetLine( n );
             OSL_ENSURE( pLine, "where is the line?" );
             sal_uLong nH = pLine->GetHashValue();
 
@@ -989,41 +1003,6 @@ void Compare::ShiftBoundaries( CompareData& rData1, CompareData& rData2 )
     lcl_ShiftBoundariesOneway(&rData2, &rData1);
 }
 
-class SwCompareLine : public CompareLine
-{
-    const SwNode& rNode;
-public:
-    explicit SwCompareLine( const SwNode& rNd );
-    virtual ~SwCompareLine();
-
-    virtual sal_uLong GetHashValue() const override;
-    virtual bool Compare( const CompareLine& rLine ) const override;
-
-    static sal_uLong GetTextNodeHashValue( const SwTextNode& rNd, sal_uLong nVal );
-    static bool CompareNode( const SwNode& rDstNd, const SwNode& rSrcNd );
-    static bool CompareTextNd( const SwTextNode& rDstNd,
-                              const SwTextNode& rSrcNd );
-
-    bool ChangesInLine( const SwCompareLine& rLine,
-                            SwPaM *& rpInsRing, SwPaM*& rpDelRing ) const;
-
-    const SwNode& GetNode() const { return rNode; }
-
-    const SwNode& GetEndNode() const;
-
-    // for debugging
-    OUString GetText() const;
-};
-
-SwCompareLine::SwCompareLine( const SwNode& rNd )
-    : rNode( rNd )
-{
-}
-
-SwCompareLine::~SwCompareLine()
-{
-}
-
 sal_uLong SwCompareLine::GetHashValue() const
 {
     sal_uLong nRet = 0;
@@ -1083,7 +1062,7 @@ const SwNode& SwCompareLine::GetEndNode() const
     return *pNd;
 }
 
-bool SwCompareLine::Compare( const CompareLine& rLine ) const
+bool SwCompareLine::Compare( const SwCompareLine& rLine ) const
 {
     return CompareNode( rNode, static_cast<const SwCompareLine&>(rLine).rNode );
 }
@@ -1522,7 +1501,7 @@ void CompareData::ShowDelete(
         static_cast<const SwCompareLine*>(rData.GetLine( nEnd-1 ))->GetEndNode(), 1 );
 
     sal_uInt16 nOffset = 0;
-    const CompareLine* pLine = 0;
+    const SwCompareLine* pLine = 0;
     if( nInsPos >= 1 )
     {
         if( GetLineCount() == nInsPos )


More information about the Libreoffice-commits mailing list
diff --git a/extensions/source/propctrlr/browserlistbox.cxx b/extensions/source/propctrlr/browserlistbox.cxx
index 72de87e..98b4a43 100644
--- a/extensions/source/propctrlr/browserlistbox.cxx
+++ b/extensions/source/propctrlr/browserlistbox.cxx
@@ -131,15 +131,15 @@ namespace pcr
         };
 
     private:
-        IControlContext*    m_pContext;
-        NotificationMode     m_eMode;
+        VclPtr<OBrowserListBox>     m_pContext;
+        NotificationMode            m_eMode;
 
     public:
         /** creates an instance
             @param _rContextImpl
                 the instance to delegate events to
         */
-        PropertyControlContext_Impl( IControlContext& _rContextImpl );
+        PropertyControlContext_Impl( OBrowserListBox& _rContextImpl );
 
         /** disposes the context.
 
@@ -150,7 +150,7 @@ namespace pcr
         void SAL_CALL dispose();
 
         /** sets the notification mode, so that notifications received from the controls are
-            forwarded to our IControlContext either synchronously or asynchronously
+            forwarded to our OBrowserListBox either synchronously or asynchronously
             @param  _eMode
                 the new notification mode
         */
@@ -172,7 +172,7 @@ namespace pcr
         virtual void processEvent( const ::comphelper::AnyEvent& _rEvent ) override;
 
     private:
         /** processes the given event, i.e. notifies it to our IControlContext
             @param  _rEvent
                 the event no notify
             @precond
@@ -200,7 +200,7 @@ namespace pcr
     };
 
 
-    PropertyControlContext_Impl::PropertyControlContext_Impl( IControlContext& _rContextImpl )
+    PropertyControlContext_Impl::PropertyControlContext_Impl( OBrowserListBox& _rContextImpl )
         :m_pContext( &_rContextImpl )
         ,m_eMode( eAsynchronously )
     {
@@ -172,7 +172,7 @@ namespace pcr
 
     private:
-        /** processes the given event, i.e. notifies it to our IControlContext
+        /** processes the given event, i.e. notifies it to our OBrowserListBox
             @param  _rEvent
                 the event no notify